@@ -3,7 +3,7 @@ use crate::workflow::AlfredWorkflow;
 use security_framework::passwords;
 
 impl AlfredWorkflow {
-    fn get_generic_password(&self, name: &str) -> String {
+    pub fn get_generic_password(&self, name: &str) -> String {
         let service = self.get_workflow_bundle_id();
         String::from_utf8(
             passwords::get_generic_password(service.as_str(), name).unwrap_or_default(),
@@ -11,7 +11,7 @@ impl AlfredWorkflow {
         .unwrap_or_default()
     }
 
-    fn set_generic_password(&self, name: &str, password: &str) -> bool {
+    pub fn set_generic_password(&self, name: &str, password: &str) -> bool {
         let service = self.get_workflow_bundle_id();
         passwords::set_generic_password(service.as_str(), name, password.as_bytes()).is_ok()
     }
